<?php

function custompage_view_tile( $name, $title='', $display_id = 'Block') {
  
  //In drupal 5
  //$view = views_get_view($name);
  //return views_build_view($mode, $view, array(), false, 5);
  
  $args = func_get_args();
  array_shift($args); // remove $name
  if (count($args)) {
    array_shift($args); // remove $title
  }
  if (count($args)) {
    array_shift($args); // remove $display_id
  }

  $view = views_get_view($name);
  
  //Use View's title unless something else explicitely indicated or 
  //$title === False, which means caller does not want title rendered
  if ( $title !== False ) {
    $title = empty($title)  ? $view->description : $title;
  }
  
  if (!$view) {
    return;
  }

  $content =  $view->preview($display_id, $args);

  if ( $title !== False ) {
    $content = "<div><h2>$title</h2>$content</div>";
  }

  $dest = substr($_SERVER['REQUEST_URI'], 1); //chop-out the leading "/"
  $editlink = l(t('Edit'), 'admin/build/views/edit/' . $name . '?destination=' . $dest );
  $editlink = urldecode($editlink); //urldecode destination argument  
  
  $tile = custompage_tile_wrap ( $content, $editlink );
  
  return $tile;

}


/**
* @param $key 
*   can be $nid of a node or a $title. If $key is not numer, it is assumed
*   to be a title and $type parameter is required. If several nodes with the
*   same title exist, only the first one will be returned.
* @param $type
*   node type
*/
function custompage_node_tile( $key, $type = '' ) {
  global $language;
  
  $langcode = $language->language; //ISO2 code
  $default = language_default();
  
  $default_langcode = $default->language;
  
  if ( is_numeric($key) ) {
    $node = node_load( array( 'nid' => $key ) );
  }
  else if ( is_string($key) && !empty($type) && is_string($type) ) {
    $node = node_load( array( 'title' => $key, 'type' => $type, 'language' => $default_langcode ) );
  }
    
  if ( !is_object($node) ) {
    return '&nbsp;';  //We should never return empty string since that makes entire page blank
                      //due to some weird bug/behaviour in Drupal. Ugh
  }
  
  $sql = 'SELECT n.nid FROM {node} n WHERE n.tnid = %d and n.language = \'%s\' ';
  $i18n_nid = db_result(db_query(db_rewrite_sql($sql), $node->nid, $langcode)); //defaults should be in default language
  
//  echo $node->nid."<pre>".print_r ( $i18n_nid,true)."</pre>";
//  exit();
  if ( is_numeric($i18n_nid) && ($i18n_nid > 0)  ) {
    $node = node_load( $i18n_nid );
  } //Serve Default language version (English usually) by default!
  
//  $content = theme('node', $node);
  $content = node_view($node, FALSE, TRUE);
  $dest = substr($_SERVER['REQUEST_URI'], 1); //chop-out the leading "/"
  $editlink = l(t('Edit'), 'node/' . $node->nid . '/edit/' . '?destination=' . $dest );
  $editlink = urldecode($editlink); //urldecode destination argument
  $tile = custompage_tile_wrap ( $content, $editlink );
  
  return $tile;
}

/**
* @param $menu_name
*   The system name of the menu as recorded in the {menu_custom} table.
*/
function custompage_menu_tile ( $menu_name ) {
  
  $out = "<ul class=\"menu-$menu_name\">";
  $menu = menu_navigation_links( $menu_name );
  foreach ( $menu as $item ) {
    //$item = _menu_link_translate( $item );
    //$item['title'] = t($item['title']);
    $item = _custompage_translate_path($item);
    $out .= "<li>".theme_menu_item_link( $item )."</li>";
  }
  
  $out .= "</ul>";
  
  $dest = substr($_SERVER['REQUEST_URI'], 1); //chop-out the leading "/"
  $editlink = l(t('Edit'), 'admin/build/menu-customize/' . $menu_name . '?destination=' . $dest);
  $editlink = urldecode($editlink); //urldecode destination argument  
  $tile = custompage_tile_wrap ( $out, $editlink );
  
  return $tile;

}

function custompage_tile_wrap ( $content, $editlink ) {
  $editlink = $editlink;
  $out = $content;
  $extraclass = '';
  if ( user_access('edit custompage tiles') ) {
    $out = '<div class="edit">' . $editlink . '</div>' . $out;
    $extraclass = 'cp_showborder';
  }
  return '<div class="cp_tile ' . $extraclass . '">' . $out . '</div>';
  
}

/**
* The idea for this function comes from the original work
* by Jonathan Hedstrom:
* @see http://www.opensourcery.com/blog/jonathan-hedstrom/drupal-6-and-primarysecondary-menu-translation
*/
function _custompage_translate_path($link) {
  global $language;
  // get a list of all available paths
  $new_paths = translation_path_get_translations($link['href']);
  if ($new_paths[$language->language]) {
    // if a translated path exists, set it here
    $link['href'] = $new_paths[$language->language];
  }
 
  // translate the title (this adds every menu title to the locale_source
  // table, for later translation
  $link['title'] = t($link['title']);
  if ($link['attributes']['title']) {
    $link['attributes']['title'] = t($link['attributes']['title']);
  }
 
  return $link;
}

